/**
 * @fileoverview Enforce links may not point to just #.
 * @author Ethan Cohen
 */
'use strict';

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var _getAttribute = require('../util/getAttribute');

var _getAttribute2 = _interopRequireDefault(_getAttribute);

var _getAttributeValue = require('../util/getAttributeValue');

var _getAttributeValue2 = _interopRequireDefault(_getAttributeValue);

var _getNodeType = require('../util/getNodeType');

var _getNodeType2 = _interopRequireDefault(_getNodeType);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var errorMessage = 'Links must not point to "#". Use a more descriptive href or use a button instead.';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var typeCheck = ['a'].concat(context.options[0]);
      var nodeType = (0, _getNodeType2.default)(node);

      // Only check 'a' elements and custom types.
      if (typeCheck.indexOf(nodeType) === -1) {
        return;
      }

      var href = (0, _getAttribute2.default)(node.attributes, 'href');
      var value = (0, _getAttributeValue2.default)(href);

      if (href && value === '#') {
        context.report({
          node: node,
          message: errorMessage
        });
      }
    }
  };
};

module.exports.schema = [{
  'oneOf': [{ 'type': 'string' }, {
    'type': 'array',
    'items': {
      'type': 'string'
    },
    'minItems': 1,
    'uniqueItems': true
  }]
}];