'use strict';

/**
 * Returns the JSXAttribute itself or undefined, indicating the attribute
 * is not present on the JSXOpeningElement. This skips over spread attributes
 * as the purpose of this linter is to do hard checks of explicit JSX props.
 *
 */

Object.defineProperty(exports, "__esModule", {
  value: true
});
var getAttribute = function getAttribute(attributesOnNode) {
  for (var _len = arguments.length, attributesToCheck = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    attributesToCheck[_key - 1] = arguments[_key];
  }

  var nodeAttribute = undefined;

  // Normalize.
  var comparators = attributesToCheck.map(function (attribute) {
    return attribute.toUpperCase();
  });

  var hasAttr = attributesOnNode.some(function (attr) {
    // If the attributes contain a spread attribute, then skip.
    if (attr.type === 'JSXSpreadAttribute') {
      return false;
    }

    // Normalize.
    if (comparators.indexOf(attr.name.name.toUpperCase()) > -1) {
      nodeAttribute = attr;
      return true;
    }

    return false;
  });

  return hasAttr ? nodeAttribute : undefined;
};

exports.default = getAttribute;